==> ama-3.1.6-sources.jar: org/duracloud/account/app/controller/GlobalPropertiesForm.java <==
/*
 * The contents of this file are subject to the license and copyright
 * detailed in the LICENSE and NOTICE files at the root of the source
 * tree and available online at
 *
 *     http://duracloud.org/license/
 */
package org.duracloud.account.app.controller;

import org.hibernate.validator.constraints.NotBlank;

/**
 * 
 * @author Daniel Bernstein
 *
 */
public class GlobalPropertiesForm {
    @NotBlank
    private String instanceNotificationTopicArn;

    @NotBlank(message = "You must specify a CloudFront Account Id")
    private String cloudFrontAccountId;

    @NotBlank(message = "You must specify a Cloud Key Id")
    private String cloudFrontKeyId;

    @NotBlank(message = "You must specify a CloudFront Key Path")
    private String cloudFrontKeyPath;
    
    
    public String getInstanceNotificationTopicArn() {
        return instanceNotificationTopicArn;
    }

    public void setInstanceNotificationTopicArn(
            String instanceNotificationTopicArn) {
        this.instanceNotificationTopicArn = instanceNotificationTopicArn;
    }       
    
    public String getCloudFrontAccountId() {
        return cloudFrontAccountId;
    }

    public void setCloudFrontAccountId(String cloudFrontAccountId) {
        this.cloudFrontAccountId = cloudFrontAccountId;
    }

    public String getCloudFrontKeyId() {
        return cloudFrontKeyId;
    }

    public void setCloudFrontKeyId(String cloudFrontKeyId) {
        this.cloudFrontKeyId = cloudFrontKeyId;
    }

    public String getCloudFrontKeyPath() {
        return cloudFrontKeyPath;
    }

    public void setCloudFrontKeyPath(String cloudFrontKeyPath) {
        this.cloudFrontKeyPath = cloudFrontKeyPath;
    }   
    
}

==> ama-5.0.0-sources.jar: org/duracloud/account/app/controller/GlobalPropertiesForm.java <==
/*
 * The contents of this file are subject to the license and copyright
 * detailed in the LICENSE and NOTICE files at the root of the source
 * tree and available online at
 *
 *     http://duracloud.org/license/
 */
package org.duracloud.account.app.controller;

import org.hibernate.validator.constraints.NotBlank;

/**
 * @author Daniel Bernstein
 */
public class GlobalPropertiesForm {
    @NotBlank
    private String instanceNotificationTopicArn;

    @NotBlank(message = "You must specify a CloudFront Account Id")
    private String cloudFrontAccountId;

    @NotBlank(message = "You must specify a Cloud Key Id")
    private String cloudFrontKeyId;

    @NotBlank(message = "You must specify a CloudFront Key Path")
    private String cloudFrontKeyPath;

    public String getInstanceNotificationTopicArn() {
        return instanceNotificationTopicArn;
    }

    public void setInstanceNotificationTopicArn(String instanceNotificationTopicArn) {
        this.instanceNotificationTopicArn = instanceNotificationTopicArn;
    }

    public String getCloudFrontAccountId() {
        return cloudFrontAccountId;
    }

    public void setCloudFrontAccountId(String cloudFrontAccountId) {
        this.cloudFrontAccountId = cloudFrontAccountId;
    }

    public String getCloudFrontKeyId() {
        return cloudFrontKeyId;
    }

    public void setCloudFrontKeyId(String cloudFrontKeyId) {
        this.cloudFrontKeyId = cloudFrontKeyId;
    }

    public String getCloudFrontKeyPath() {
        return cloudFrontKeyPath;
    }

    public void setCloudFrontKeyPath(String cloudFrontKeyPath) {
        this.cloudFrontKeyPath = cloudFrontKeyPath;
    }

}
